[MOAB-dev] r1905 - MOAB/trunk/tools/mbcoupler

tautges at mcs.anl.gov tautges at mcs.anl.gov
Tue Jun 17 14:18:45 CDT 2008


Author: tautges
Date: 2008-06-17 14:18:45 -0500 (Tue, 17 Jun 2008)
New Revision: 1905

Modified:
   MOAB/trunk/tools/mbcoupler/MBCoupler.cpp
Log:
Fixing a couple of obvious bugs.


Modified: MOAB/trunk/tools/mbcoupler/MBCoupler.cpp
===================================================================
--- MOAB/trunk/tools/mbcoupler/MBCoupler.cpp	2008-06-17 18:33:38 UTC (rev 1904)
+++ MOAB/trunk/tools/mbcoupler/MBCoupler.cpp	2008-06-17 19:18:45 UTC (rev 1905)
@@ -103,7 +103,7 @@
       // <marco...>
 
       // for any point/element with nat coords within bounds, store
       // handle/nat coords in vector, and proc/index in outgoing tuple
       // (-1 for index if no elements containing that point)
       // <marco...>
     
@@ -149,7 +149,7 @@
     // copy into tl if passed in and storing locally
   if (tl && store_local) {
     tuple_list_init_max(tl, 3, 0, 0, 1, num_pts);
-    memcpy(tl->vi, tl_tmp->vi, 3*sizeof(int));
+    memcpy(tl->vi, tl_tmp->vi, 3*num_pts*sizeof(int));
     tl->n = tl_tmp->n;
   }
   
@@ -103,7 +103,7 @@
 
       // for any point/element with nat coords within bounds, store
-      // handle/nat coords in vector, and proc/index in outgoing tuple
+      // handle/nat coords in mappedPts, and proc/index in outgoing tuple
       // (-1 for index if no elements containing that point)
       // <marco...>




More information about the moab-dev mailing list